@@ -4,8 +4,8 @@ stepspy - Python Module for Wrapping STEPS Dynamic Liabrary
 """
 __all__ = ['help']
 __author__ = "Changgang Li <lichgang@sdu.edu.cn>"
-__date__ = "April 22, 2020"
-__version__ = "1.0.0"
+__date__ = "Oct 20, 2020"
+__version__ = "1.5.3"
 
 from .stepspy import STEPS
 from .pouch import POUCH, POUCH_CSV, POUCH_STEPS
