@@ -2,9 +2,6 @@ from ctypes import *
 import platform
 import os
 
-libsteps_version = "0.13.0"
-libsteps_date = "2020/09/09"
-
 def get_base_library():
     dirname, filename = os.path.split(os.path.abspath(__file__))
     dirname = dirname.replace('\\','/')
@@ -36,6 +33,32 @@ def load_library():
     else:
         return None
 
+    libsteps.api_get_api_major_version.restype = c_uint
+    libsteps.api_get_api_major_version.argtype = None
+    libsteps.api_get_api_minor_version.restype = c_uint
+    libsteps.api_get_api_minor_version.argtype = None
+    libsteps.api_get_api_patch_version.restype = c_uint
+    libsteps.api_get_api_patch_version.argtype = None
+
+    major_version = libsteps.api_get_api_major_version()
+    minor_version = libsteps.api_get_api_minor_version()
+    patch_version = libsteps.api_get_api_patch_version()
+
+    required_major_version = 1
+    required_minor_version = 5
+    required_patch_version = 2
+
+    valid_flag = major_version >= required_major_version
+    if valid_flag==True and major_version==required_major_version:
+        valid_flag = valid_flag and minor_version>=required_minor_version
+    if valid_flag==True and major_version==required_major_version and minor_version==required_minor_version:
+        valid_flag = valid_flag and patch_version>=required_patch_version
+    
+    if valid_flag==False:
+        print("Invalid libsteps version {}.{}.{}. Version >= {}.{}.{} is required.".format(
+            major_version, minor_version, patch_version, required_major_version, required_minor_version, required_patch_version))
+        return None
+
     libsteps.api_get_const_INDEX_NOT_EXIST.restype = c_uint
     libsteps.api_get_const_INDEX_NOT_EXIST.argtype = None
     
@@ -92,9 +115,9 @@ def load_library():
     libsteps.api_load_dynamic_data_from_file.argtypes = (c_char_p, c_char_p, c_uint)
 
     libsteps.api_save_powerflow_data_to_file.restype = None
-    libsteps.api_save_powerflow_data_to_file.argtypes = (c_char_p, c_char_p, c_bool, c_bool, c_uint, c_uint)
+    libsteps.api_save_powerflow_data_to_file.argtypes = (c_char_p, c_char_p, c_bool, c_bool, c_bool, c_uint, c_uint)
     libsteps.api_save_dynamic_data_to_file.restype = None
-    libsteps.api_save_dynamic_data_to_file.argtypes = (c_char_p, c_char_p, c_uint)
+    libsteps.api_save_dynamic_data_to_file.argtypes = (c_char_p, c_char_p, c_bool, c_uint)
     
     libsteps.api_check_powerflow_data.restype = None
     libsteps.api_check_powerflow_data.argtypes = (c_uint, )
@@ -462,6 +485,14 @@ def load_library():
     libsteps.api_get_generator_related_model_float_parameter_count.argtypes = (c_uint, c_char_p, c_char_p, c_uint)
     libsteps.api_get_generator_related_model_float_parameter_name.restype = c_char_p
     libsteps.api_get_generator_related_model_float_parameter_name.argtypes = (c_uint, c_char_p, c_char_p, c_uint, c_uint)
+    libsteps.api_get_generator_related_model_internal_variable_count.restype = c_uint
+    libsteps.api_get_generator_related_model_internal_variable_count.argtypes = (c_uint, c_char_p, c_char_p, c_uint)
+    libsteps.api_get_generator_related_model_internal_variable_with_name.restype = c_double
+    libsteps.api_get_generator_related_model_internal_variable_with_name.argtypes = (c_uint, c_char_p, c_char_p, c_char_p, c_uint)
+    libsteps.api_get_generator_related_model_internal_variable_with_index.restype = c_double
+    libsteps.api_get_generator_related_model_internal_variable_with_index.argtypes = (c_uint, c_char_p, c_char_p, c_uint, c_uint)
+    libsteps.api_get_generator_related_model_internal_variable_name.restype = c_char_p
+    libsteps.api_get_generator_related_model_internal_variable_name.argtypes = (c_uint, c_char_p, c_char_p, c_uint, c_uint)
 
     libsteps.api_get_wt_generator_related_model_name.restype = c_char_p
     libsteps.api_get_wt_generator_related_model_name.argtypes = (c_uint, c_char_p, c_char_p, c_uint)
